body {
  background-color: #E1D1F1;
  font-family: "Georgia", sans-serif;
  font-size: 16px;
  line-height: 1.6em;
  padding: 1.6em 0 0 0;
  color: #333;
}
h1, h2, h3, h4, h5, h6 {
  color: #444;
}
h1 { 
  font-family: sans-serif;
  font-weight: normal;
  font-size: 4em;
  line-height: 0.8em;
  letter-spacing: -0.1ex;
	margin: 5px;
}
li {
  padding: 0;
  margin: 0;
  list-style-type: square;
}
a {
  color: #5E5AFF;
	background-color: #DAC;
  font-weight: normal;
  text-decoration: underline;
}
blockquote {
  font-size: 90%;
  font-style: italic;
  border-left: 1px solid #111;
  padding-left: 1em;
}
.caps {
  font-size: 80%;
}

#main {
  width: 45em;
  padding: 0;
  margin: 0 auto;
}
.coda {
  text-align: right;
  color: #77f;
  font-size: smaller;
}

table {
  font-size: 90%;
  line-height: 1.4em;
  color: #ff8;
  background-color: #111;
  padding: 2px 10px 2px 10px;
	border-style: dashed;
}

th {
	color: #fff;
}

td {
  padding: 2px 10px 2px 10px;
}

.success {
	color: #0CC52B;
}

.failed {
	color: #E90A1B;
}

.unknown {
	color: #995000;
}
pre, code {
  font-family: monospace;
  font-size: 90%;
  line-height: 1.4em;
  color: #ff8;
  background-color: #111;
  padding: 2px 10px 2px 10px;
}
.comment { color: #aaa; font-style: italic; }
.keyword { color: #eff; font-weight: bold; }
.punct { color: #eee; font-weight: bold; }
.symbol { color: #0bb; }
.string { color: #6b4; }
.ident { color: #ff8; }
.constant { color: #66f; }
.regex { color: #ec6; }
.number { color: #F99; }
.expr { color: #227; }

#version {
  float: right;
  text-align: right;
  font-family: sans-serif;
  font-weight: normal;
  background-color: #B3ABFF;
  color: #141331;
  padding: 15px 20px 10px 20px;
  margin: 0 auto;
	margin-top: 15px;
  border: 3px solid #141331;
}

#version .numbers {
  display: block;
  font-size: 4em;
  line-height: 0.8em;
  letter-spacing: -0.1ex;
	margin-bottom: 15px;
}

#version p {
  text-decoration: none;
	color: #141331;
	background-color: #B3ABFF;
	margin: 0;
	padding: 0;
}

#version a {
  text-decoration: none;
	color: #141331;
	background-color: #B3ABFF;
}

.clickable {
	cursor:	pointer; 
	cursor:	hand;
}

